@@ -11,6 +11,8 @@ from sem_reject.deliverable_util import (ConverterForRequest,
                               export_as_vector_deliverable_model,
                               export_as_deliverable_model,
                               ConverterForResponse)
+from sem_reject.core import input_data_process, build_model
+
 
 def main():
     # get configure
@@ -28,7 +30,6 @@ def main():
     EMBED_DIM = config.get("embedding_dim", 128)
 
     # get preprocessed input data dict
-    from sem_reject.core import input_data_process
     # to build a fixed training environment, input data should be fixed.
     # input_data should be shuffled and remove duplication outside the trainer before running the program.
     # input data should be corpus(no duplication, shuffle well)
@@ -43,7 +44,7 @@ def main():
     cls_test_x, cls_test_y = data_dict['cls_test_x'], data_dict['cls_test_y']
 
     # build model or finetuning
-    from core import build_model
+
     params = {'EMBED_DIM': EMBED_DIM,
               'input_length': MAX_SENTENCE_LEN,
               'vocab_size': vocabulary_lookuper.size(),
